@@ -52,6 +52,7 @@
 using namespace KIO;
 
 BatchRenamer::BatchRenamer()
+    : m_index( 0 )
 {
     plug = PluginLoader::instance();
     m_counter_index = 0;
@@ -99,13 +100,14 @@ void BatchRenamer::processFiles( ProgressDialog* p, QObject* object )
         parseSubdirs( &m_files[i] );
         // TODO: DOM 
         // ESCAPE HERE
-        
+   
         m_files[i].src.name = BatchRenamer::buildFilename( &m_files[i].src, true );
-        m_files[i].dst.name = BatchRenamer::buildFilename( &m_files[i].dst, true );
 
         // Let's run the plugins that change the final filename,
         // i.e the encodingsplugin
         m_files[i].dst.name = parsePlugins( i, m_files[i].dst.name, TYPE_FINAL_FILENAME );
+
+        m_files[i].dst.name = BatchRenamer::buildFilename( &m_files[i].dst, true );
                 
         /*
          * take care of renamed directories and
@@ -145,7 +147,6 @@ QString BatchRenamer::processString( QString text, QString oldname, int i )
      * better one please tell me about it!
      */
      
-
     doEscape( oldname );
     /*
      * Call here all functions that handle
@@ -216,15 +217,14 @@ void BatchRenamer::createPreview( QListView* list )
 
         bool modified = applyManualChanges( i );
 
+
         QString sname = BatchRenamer::buildFilename( &m_files[i].src, false );
+
+        // Let's run the plugins that change the final filename,
+        // i.e the encodingsplugin
+        m_files[i].dst.name = parsePlugins( i, m_files[i].dst.name, TYPE_FINAL_FILENAME );
         QString dname = BatchRenamer::buildFilename( &m_files[i].dst, false );
         
-        // Let's run the plugins that change the final filename,
-        // i.e the encodingsplugin
-        // Let's run the plugins that change the final filename,
-        // i.e the encodingsplugin
-        dname = parsePlugins( i, dname, TYPE_FINAL_FILENAME );
-        
         item1 = new KMyListViewItem( modified, list, item1, sname, dname );
     }
 }
